@@ -36,7 +36,6 @@
 #define SsnDebug(ssn, tag, ...) SpecificDebug((ssn)->debug(), tag, __VA_ARGS__)
 
 class ProxyClientTransaction;
-struct AclRecord;
 
 enum class ProxyErrorClass {
   NONE,
@@ -213,9 +212,10 @@ public:
     return con_id;
   }
 
-  virtual void
+  virtual bool
   attach_server_session(HttpServerSession *ssession, bool transaction_done = true)
   {
+    return false;
   }
 
   virtual HttpServerSession *
@@ -285,9 +285,6 @@ public:
     return netvc ? netvc->get_local_addr() : nullptr;
   }
 
-  /// acl record - cache IpAllow::match() call
-  const AclRecord *acl_record = nullptr;
-
   /// Local address for outbound connection.
   IpAddr outbound_ip4;
   /// Local address for outbound connection.
